@@ -1,5 +1,5 @@
 /* GADMIN-SAMBA, an easy to use GTK+ frontend for the SAMBA file and print server.
- * Copyright (C) 2006 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006 - 2011 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -425,15 +425,6 @@ void add_share(struct w *widgets)
       opt = g_strdup_printf("printable = no\n");
     strcat(new_conf, opt);
 
-/*  "Share modes" has been deprecated.
-    active_index = gtk_combo_box_get_active(GTK_COMBO_BOX(widgets->share_set_combo[7]));
-    if( active_index == 0 )
-      opt = g_strdup_printf("share modes = yes\n");
-    else
-      opt = g_strdup_printf("share modes = no\n");
-    strcat(new_conf, opt);
-*/
-
     active_index = gtk_combo_box_get_active(GTK_COMBO_BOX(widgets->share_set_combo[7]));
     if( active_index == 0 )
       opt = g_strdup_printf("locking = yes\n");
