@@ -1,5 +1,5 @@
 /* GADMIN-SAMBA, an easy to use GTK+ frontend for the SAMBA file and print server.
- * Copyright (C) 2006 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006 - 2011 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -219,9 +219,23 @@ void create_import_selection(struct w *widgets)
     gtk_widget_show_all(widgets->import_window);
 
 
+
     /* Populate the import treeview with LOCAL users and groups except machine accounts */
     if( global_import_local )
     {
+	/* First add macros for all users and groups.
+	   FIX: Make translatable after modifying the recieving functions. */
+	gtk_list_store_append(GTK_LIST_STORE(widgets->import_store), &iter);
+	import_msg = g_strdup_printf("All users");
+	utf8 = g_locale_to_utf8(import_msg, strlen(import_msg), NULL, NULL, NULL);
+	gtk_list_store_set(GTK_LIST_STORE(widgets->import_store), &iter, 0, utf8, -1);
+	g_free(import_msg);
+	import_msg = g_strdup_printf("All groups");
+	utf8 = g_locale_to_utf8(import_msg, strlen(import_msg), NULL, NULL, NULL);
+	gtk_list_store_set(GTK_LIST_STORE(widgets->import_store), &iter, 1, utf8, -1);
+	g_free(import_msg);
+
+
 	if((fp=fopen(PASSWD_FILE, "r"))==NULL)
 	{
     	    printf("Cant open passwd here:\n%s\n", PASSWD_FILE);
