@@ -1,5 +1,5 @@
 /* GADMIN-SAMBA, an easy to use GTK+ frontend for the SAMBA file and print server.
- * Copyright (C) 2006 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006 - 2011 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -193,15 +193,19 @@ void del_share_access_clicked(GtkButton *button, struct w *widgets)
 
 void select_share_path_clicked(struct w *widgets)
 {
-    gchar *path = NULL;
+    gchar *path = NULL, *sharesdir = NULL;
+    
+    sharesdir = g_strdup_printf("%s/lib/samba", LOCALSTATEDIR);
 
-    path = get_dialog_path_selection("DIR", "/var/samba", "None");
+    path = get_dialog_path_selection("DIR", sharesdir, "None");
     if( path!=NULL )
     {
         printf("Selected directory: %s\n", path);
         gtk_entry_set_text(GTK_ENTRY(widgets->share_set_entry[1]), path);
         g_free(path);
     }
+
+    g_free(sharesdir);
 }
 
 
@@ -613,19 +617,7 @@ void create_share_settings(struct w *widgets)
     g_free(combo_text); g_free(utf8);
     a++; b++; comb++;
 
-/*  "share modes" Has been deprecated.
-    widgets->share_set_combo[comb] = make_label_combo_label(GTK_TABLE(widgets->share_set_table), _(" Share modes: "), 0,1,a,b, 80);
-    combo_text = g_strdup_printf(_("Yes"));
-    utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
-    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->share_set_combo[comb]), utf8);
-    combo_text = g_strdup_printf(_("No"));
-    utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
-    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->share_set_combo[comb]), utf8);
-    g_free(combo_text); g_free(utf8);
-    a++; b++; comb++;
-*/
-
-    /* locking combo */
+    /* File locking combo */
     widgets->share_set_combo[comb] = make_label_combo_label(GTK_TABLE(widgets->share_set_table), _(" File locking: "), 0,1,a,b, 80);
     combo_text = g_strdup_printf(_("Yes"));
     utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
@@ -636,7 +628,7 @@ void create_share_settings(struct w *widgets)
     g_free(combo_text); g_free(utf8);
     a++; b++; comb++;
 
-    /* Strict locking */
+    /* Strict file locking */
     widgets->share_set_combo[comb] = make_label_combo_label(GTK_TABLE(widgets->share_set_table), _(" Strict locking: "), 0,1,a,b, 80);
     combo_text = g_strdup_printf(_("Yes"));
     utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
