@@ -1,5 +1,5 @@
 /* GADMIN-SAMBA, an easy to use GTK+ frontend for the SAMBA file and print server.
- * Copyright (C) 2006 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006 - 2011 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -672,8 +672,9 @@ gchar *get_group_name(gchar *groupnr)
     }
 
     free(temp);
-    
-    retval = g_strdup_printf(_("Group name not found"));
+
+    /* New default samba group if not found. */    
+    retval = g_strdup_printf("sambausers");
 
     return retval;
 }
@@ -786,7 +787,21 @@ gchar *get_user_setting(gchar *user, gchar *what)
     if( found_val )
       return retval;
 
-    retval = g_strdup_printf(_("No value has been set"));
+    /* Return values if not found. Same as in
+       add_change_user.c's clear_user_profile() */
+    if( strstr(what, "group") )
+      retval = g_strdup_printf("group1");
+    else
+    if( strstr(what, "comment") )
+      retval = g_strdup_printf(_("Comment"));
+    else
+    if( strstr(what, "homedir") )
+      retval = g_strdup_printf("/home/user1");
+    else
+    if( strstr(what, "shell") )
+      retval = g_strdup_printf("/dev/null");
+    else
+      retval = g_strdup_printf(_("No value has been set"));
 
     return retval;
 }
@@ -912,7 +927,7 @@ void make_dir_chmod(gchar *directory, char perm[128])
 {
     gchar *command;
     
-    command = g_strdup_printf("mkdir -p %s && chmod %s %s", directory, perm, directory);
+    command = g_strdup_printf("mkdir -p '%s' && chmod %s '%s'", directory, perm, directory);
     if( ! run_command(command) )
       printf("Error running command: %s\n", command);    
 
@@ -924,7 +939,7 @@ void make_file_chmod(gchar *file, char perm[128])
 {
     gchar *command;
     
-    command = g_strdup_printf("touch %s && chmod %s %s", file, perm, file);
+    command = g_strdup_printf("touch '%s' && chmod %s '%s'", file, perm, file);
     if( ! run_command(command) )
       printf("Error running command: %s\n", command);    
 
