@@ -1,5 +1,5 @@
 /* GADMIN-SAMBA, an easy to use GTK+ frontend for the SAMBA file and print server.
- * Copyright (C) 2006 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006 - 2011 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -59,10 +59,12 @@ void set_version(struct w *widgets)
     
     while(fgets(version, MAX_READ_POPEN, fp)!=NULL)
     {
-       if( strstr(version, "Version") && strlen(version) < 30 )
+       if( strstr(version, "Version") )
        {
-    	  /* We cut out th first 3 chars " _ " */
+    	  /* Insert trimmed version */
           ver = g_strdup_printf(_(" Information: SAMBA %s"), &version[8]);
+	  if( ver!=NULL && strlen(ver) > 50 )
+	    ver[50]='\0';
 	  utf8 = g_locale_to_utf8(ver, strlen(ver)-1, NULL, NULL, NULL);
           gtk_label_set_text(GTK_LABEL(widgets->version_label), utf8);
 	  g_free(utf8);
