@@ -1,5 +1,5 @@
 /* GADMIN-SAMBA, an easy to use GTK+ frontend for the SAMBA file and print server.
- * Copyright (C) 2006 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006 - 2011 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -68,7 +68,7 @@ void show_settings_window(struct w *widgets)
 
 
     tooltips = gtk_tooltips_new();
-    frame = gtk_frame_new("Settings:");
+    frame = gtk_frame_new(_("Settings:"));
 
     /* A table with 6 settings and 2 columns */
     table = gtk_table_new(6, 2, FALSE);
