@@ -1,5 +1,5 @@
 /* GADMIN-SAMBA, an easy to use GTK+ frontend for the SAMBA file and print server.
- * Copyright (C) 2006 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006 - 2011 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -70,9 +70,9 @@ void show_help()
 
   _("\nUsers:\n"),
   _("Adding a user can be done by specifying its username, group, password\n"),
-  _("and other settings, then clicking add.\n"),
+  _("and other settings, then clicking apply.\n"),
   _("After one user has been added this user can serve as a profile for other users.\n"),
-  _("Select a user in the user list, change its username and password then click add.\n"),
+  _("Select a user in the user list, change its username and password then click apply.\n"),
   _("Both users will then have the same settings except for the username and password.\n"),
   _("The new user button can be used to clear and insert default user settings, making it\n"),
   _("ready for adding new users.\n\n"),
@@ -107,7 +107,7 @@ void show_help()
   _("field then press join domain. Use root as username and the samba root password in the dialog.\n\n"),
     
   _("Joining the domain with Linux or other open source clients:\n"),
-  _("net rpc join example.org -S samba24 -U root then supply the samba root password\n"),
+  _("net rpc join example.org -S samba24 -U root then supply the samba root password\n\n"),
 
 
   _("Mounting shares:\n"),
