@@ -1,5 +1,5 @@
 /* GADMIN-SAMBA, an easy to use GTK+ frontend for the SAMBA file and print server.
- * Copyright (C) 2006 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006 - 2011 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -233,7 +233,7 @@ void add_standard_conf(struct w *widgets)
 
     strcat(buffer, "passwd program = /usr/bin/passwd '%u'\n");
 
-/* Doesnt seem to work    info = g_strdup_printf("root directory = %s/samba/root\n", LOCALSTATEDIR);
+/* Doesnt seem to work    info = g_strdup_printf("root directory = %s/lib/samba/root\n", LOCALSTATEDIR);
     strcat(buffer, info);
     g_free(info);
 */
@@ -260,21 +260,12 @@ void add_standard_conf(struct w *widgets)
     strcat(buffer, "winbind refresh tickets = no\n");
     strcat(buffer, "winbind offline logon = no\n");
 
-/*
-;Begin Not working ???
-;announce as = win95
-;announce version = 42
-;FIXME COMBOBOX: announce as = "NT Server"
-;|NT|NT Server|NT Workstation|win95|WfW|
-;End Not working ???
-*/
-
-
     /* Shared home directories */
     strcat(buffer, "\n");
     strcat(buffer, "[homes]\n");
     strcat(buffer, "comment = Home Directories\n");
     strcat(buffer, "path = /home\n");
+    strcat(buffer, "valid users = %U\n");
     strcat(buffer, "read only = no\n");
     strcat(buffer, "available = yes\n");
     strcat(buffer, "browseable = yes\n");
@@ -282,14 +273,15 @@ void add_standard_conf(struct w *widgets)
     strcat(buffer, "guest ok = no\n");
     strcat(buffer, "public = no\n");
     strcat(buffer, "printable = no\n");
-// Deprecated    strcat(buffer, "share modes = no\n");
     strcat(buffer, "locking = no\n");
     strcat(buffer, "strict locking = no\n");
 
     strcat(buffer, "\n");
     strcat(buffer, "[netlogon]\n");
     strcat(buffer, "comment = Network Logon Service\n");
-    strcat(buffer, "path = /home/netlogon\n");
+    strcat(buffer, "path = ");
+    strcat(buffer, LOCALSTATEDIR);
+    strcat(buffer, "/lib/samba/netlogon\n");
     strcat(buffer, "read only = no\n");
     strcat(buffer, "available = yes\n");
     strcat(buffer, "browseable = yes\n");
@@ -297,7 +289,6 @@ void add_standard_conf(struct w *widgets)
     strcat(buffer, "guest ok = no\n");
     strcat(buffer, "public = no\n");
     strcat(buffer, "printable = no\n");
-// Deprecated    strcat(buffer, "share modes = no\n");
     strcat(buffer, "locking = no\n");
     strcat(buffer, "strict locking = no\n");
 
@@ -306,14 +297,12 @@ void add_standard_conf(struct w *widgets)
     strcat(buffer, "\n");
     strcat(buffer, "[profiles]\n"); /* This must be writable */
     strcat(buffer, "comment = User Profiles\n");
-
     strcat(buffer, "path = ");
     strcat(buffer, LOCALSTATEDIR);
-    strcat(buffer, "/samba/profiles\n");
-
+    strcat(buffer, "/lib/samba/profiles\n");
     strcat(buffer, "read only = no\n");
     strcat(buffer, "available = yes\n");
-    strcat(buffer, "browseable = no\n");
+    strcat(buffer, "browseable = yes\n");
     strcat(buffer, "writable = yes\n");
     strcat(buffer, "guest ok = no\n");
     strcat(buffer, "public = no\n");
@@ -323,7 +312,6 @@ void add_standard_conf(struct w *widgets)
     strcat(buffer, "locking = no\n");
     strcat(buffer, "strict locking = no\n");
     
-
     strcat(buffer, "\n");
     strcat(buffer, "[printers]\n");
     strcat(buffer, "comment = All Printers\n");
@@ -335,7 +323,6 @@ void add_standard_conf(struct w *widgets)
     strcat(buffer, "guest ok = no\n");
     strcat(buffer, "public = no\n");
     strcat(buffer, "printable = yes\n");
-//Deprecated    strcat(buffer, "share modes = no\n");
     strcat(buffer, "locking = no\n");
     strcat(buffer, "strict locking = no\n");
 
@@ -343,8 +330,11 @@ void add_standard_conf(struct w *widgets)
     /* We want to be able to print anything as pdf documents to a directory */
     strcat(buffer, "\n");
     strcat(buffer, "[pdf-documents]\n");
-    strcat(buffer, "path = /home/pdf-documents\n");
+    strcat(buffer, "path = ");
+    strcat(buffer, LOCALSTATEDIR);
+    strcat(buffer, "/lib/samba/pdf-documents\n");
     strcat(buffer, "comment = Converted PDF Documents\n");
+    strcat(buffer, "admin users = %U\n");
     strcat(buffer, "available = yes\n");
     strcat(buffer, "browseable = yes\n");
     strcat(buffer, "writeable = yes\n");
@@ -376,39 +366,17 @@ void add_standard_conf(struct w *widgets)
     populate_gadmin_samba(widgets);
 
     /* Create default directories */
-    cmd = g_strdup_printf("mkdir -p /home/netlogon /home/pdf-documents %s/samba/profiles/root %s/log/samba\n", LOCALSTATEDIR, LOCALSTATEDIR);
+    cmd = g_strdup_printf("mkdir -p '%s/lib/samba/netlogon' '%s/lib/samba/pdf-documents' '%s/lib/samba/profiles/root' '%s/log/samba'\n",
+    LOCALSTATEDIR, LOCALSTATEDIR, LOCALSTATEDIR, LOCALSTATEDIR);
     if((fp=popen(cmd, "w"))==NULL)
     {
         perror("popen");
-        info = g_strdup_printf(_("Failed to create directories:\n%s\n"), "/home/netlogon, /home/pdf-documents and /var/samba/profiles/root");
-        show_info(info);
-	g_free(info);
-        g_free(cmd);
-        return;
-    }
-    pclose(fp);
-    g_free(cmd);
-
-    /* Chmod the netlogon directory with a+r */
-    cmd = g_strdup_printf("%s /home/netlogon\n", "chmod a+r");
-    if((fp=popen(cmd, "w"))==NULL)
-    {
-        perror("popen");
-        info = g_strdup_printf(_("Failed chmodding a+r for directory: %s\n"), "/home/netlogon");
-        show_info(info);
-	g_free(info);
-        g_free(cmd);
-        return;
-    }
-    pclose(fp);
-    g_free(cmd);
-
-    /* Chown the profiles directory */
-    cmd = g_strdup_printf("chown root:nobody %s/samba/profiles /home/pdf-documents\n", LOCALSTATEDIR);
-    if((fp=popen(cmd, "w"))==NULL)
-    {
-        perror("popen");
-        info = g_strdup_printf(_("Failed chowning the directories: %s\n"), "/var/samba/profiles /home/pdf-documents");
+        info = g_strconcat(_("Failed to create directories:\n%s\n"),
+        LOCALSTATEDIR, "/lib/samba/netlogon\n",
+        LOCALSTATEDIR, "/lib/samba/pdf-documents\n",
+        LOCALSTATEDIR, "/lib/samba/profiles/root\n",
+        LOCALSTATEDIR, "/log/samba\n",
+        NULL);
         show_info(info);
 	g_free(info);
         g_free(cmd);
@@ -418,25 +386,11 @@ void add_standard_conf(struct w *widgets)
     g_free(cmd);
 
     /* Chmod the profiles directory */
-    cmd = g_strdup_printf("chmod 755 %s/samba/profiles\n", LOCALSTATEDIR);
+    cmd = g_strdup_printf("chmod 1755 %s/lib/samba/profiles\n", LOCALSTATEDIR);
     if((fp=popen(cmd, "w"))==NULL)
     {
         perror("popen");
-        info = g_strdup_printf(_("Failed chmodding directory: %s\n"), "/var/samba/profiles");
-        show_info(info);
-	g_free(info);
-        g_free(cmd);
-        return;
-    }
-    pclose(fp);
-    g_free(cmd);
-
-    /* Chmod the pdf-documents directory, must be writable by user nobody */
-    cmd = g_strdup_printf("%s /home/pdf-documents\n", "chmod a+rw");
-    if((fp=popen(cmd, "w"))==NULL)
-    {
-        perror("popen");
-        info = g_strdup_printf(_("Failed chmodding directory: %s\n"), "/home/pdf-documents");
+        info = g_strdup_printf(_("Failed chmodding directory: %s/lib/samba/profiles\n"), LOCALSTATEDIR);
         show_info(info);
 	g_free(info);
         g_free(cmd);
@@ -446,11 +400,11 @@ void add_standard_conf(struct w *widgets)
     g_free(cmd);
 
     /* Create the samba root users home directory */
-    cmd = g_strdup_printf("mkdir -p %s/samba/root\n", LOCALSTATEDIR);
+    cmd = g_strdup_printf("mkdir -p '%s/lib/samba/root'\n", LOCALSTATEDIR);
     if((fp=popen(cmd, "w"))==NULL)
     {
         perror("popen");
-        info = g_strdup_printf(_("Failed to create directory: %s/%s\n"), LOCALSTATEDIR, "/samba/root");
+        info = g_strdup_printf(_("Failed to create directory: %s/%s\n"), LOCALSTATEDIR, "/lib/samba/root");
         show_info(info);
 	g_free(info);
         g_free(cmd);
@@ -592,7 +546,7 @@ void create_standard_conf_question(struct w *widgets)
     /* The gadmin-samba settings directory doesnt exist, make it (could be due to bad packaging etc) */
     if( ! file_exists(APPCONFDIR) )
     {
-	cmd = g_strdup_printf("mkdir -p %s", APPCONFDIR);
+	cmd = g_strdup_printf("mkdir -p '%s'", APPCONFDIR);
 	if( ! run_command(cmd) )
 	{
     	    info = g_strdup_printf(_("Error: cant create the settings directory here:\n%s\n"), APPCONFDIR);
